#!/usr/bin/env python

from setuptools import find_packages, setup

setup(
    name="apispec-deco",
    version="0.0.1",
    description="Syntactic sugar for apispec",
    platforms="all",
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Development Status :: 1 - Planning",
    ],
    python_requires=">=3.7",
    zip_safe=False,
)
